Summary:          A suite of tools for compiling mdoc and man
Name:             mandoc
Version:          1.14.6
Release:          5%{?dist}
License:          ISC

# Unfortunately, we can not visit https://mandoc.bsd.lv
URL:              https://en.wikipedia.org/wiki/Mandoc
Source0:          https://fossies.org/linux/misc/mandoc-%{version}.tar.gz
Source1:          configure.local

BuildRequires:    gcc make zlib-devel perl-interpreter perl(IPC::Open3)

Requires(post):   %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives
Requires(preun):  %{_sbindir}/update-alternatives

Provides:         libmandoc = %{version}-%{release}

%description
mandoc is a suite of tools compiling mdoc, the roff macro language of choice for BSD manual pages,
and man, the predominant historical language for UNIX manuals. It is small, ISO C, ISC-licensed, and
quite fast. The main component of the toolset is the mandoc utility program, based on the libmandoc
validating compiler, to format output for UTF-8 and ASCII UNIX terminals, HTML 5, PostScript, and
PDF.

%package -n libmandoc-devel
Summary:        Development libraries and headers for libmandoc

%description -n libmandoc-devel
The mandoc library parses a UNIX manual into an abstract syntax tree (AST).  UNIX manuals are
composed of mdoc(7) or man(7), and may be mixed with roff(7), tbl(7), and eqn(7) invocations.

%prep
%autosetup -n %{name}-%{version} -p1
cp %{SOURCE1} .
echo 'CFLAGS="%{optflags} -fPIC"' >> configure.local

%build
./configure
%make_build

%install
%make_install

chmod -x %{buildroot}%{_includedir}/*.h

for name in man apropos whatis soelim; do
    mv %{buildroot}%{_bindir}/$name %{buildroot}%{_bindir}/$name.mandoc
done

for name in apropos man soelim whatis; do
    mv %{buildroot}%{_mandir}/man1/$name.1 %{buildroot}%{_mandir}/man1/$name.mandoc.1
done

for name in man roff eqn tbl; do
    mv %{buildroot}%{_mandir}/man7/$name.7 %{buildroot}%{_mandir}/man7/$name.mandoc.7
done

mv %{buildroot}%{_mandir}/man8/makewhatis.8 %{buildroot}%{_mandir}/man8/makewhatis.mandoc.8
mv %{buildroot}%{_sbindir}/makewhatis %{buildroot}%{_sbindir}/makewhatis.mandoc

touch %{buildroot}%{_bindir}/{man,apropos,whatis,soelim}
touch %{buildroot}%{_sbindir}/makewhatis
touch %{buildroot}%{_mandir}/man1/{apropos,man,soelim,whatis}.1
touch %{buildroot}%{_mandir}/man7/{man,roff,eqn,tbl}.7
touch %{buildroot}%{_mandir}/man8/makewhatis.8

%check
env LD_LIBRARY_PATH="$PWD" %make_build regress

%postun
if [ $1 -ge 1 ]; then
    if [ "$(readlink %{_sysconfdir}/alternatives/man)" = "%{_bindir}/man.mandoc" ]; then
        %{_sbindir}/alternatives --set man %{_bindir}/man.mandoc
    fi

    if [ "$(readlink %{_sysconfdir}/alternatives/soelim)" = "%{_bindir}/soelim.mandoc" ]; then
        %{_sbindir}/alternatives --set soelim %{_bindir}/soelim.mandoc
    fi

    if [ "$(readlink %{_sysconfdir}/alternatives/roff.7.gz)" = "%{_mandir}/man7/roff.mandoc.7.gz" ]; then
        %{_sbindir}/alternatives --set roff.7.gz %{_mandir}/man7/roff.mandoc.7.gz
    fi

    if [ "$(readlink %{_sysconfdir}/alternatives/man.7.gz)" = "%{_mandir}/man7/man.mandoc.7.gz" ]; then
        %{_sbindir}/alternatives --set man.7.gz %{_mandir}/man7/man.mandoc.7.gz
    fi
fi

%post
%{_sbindir}/update-alternatives --install %{_bindir}/man man %{_bindir}/man.mandoc 200 \
    --slave %{_bindir}/apropos apropos %{_bindir}/apropos.mandoc \
    --slave %{_bindir}/whatis whatis %{_bindir}/whatis.mandoc \
    --slave %{_sbindir}/makewhatis makewhatis %{_sbindir}/makewhatis.mandoc \
    --slave %{_mandir}/man1/apropos.1.gz apropos.1.gz %{_mandir}/man1/apropos.mandoc.1.gz \
    --slave %{_mandir}/man1/man.1.gz man.1.gz %{_mandir}/man1/man.mandoc.1.gz \
    --slave %{_mandir}/man1/whatis.1.gz whatis.1.gz %{_mandir}/man1/whatis.mandoc.1.gz \
    --slave %{_mandir}/man8/makewhatis.8.gz makewhatis.8.gz %{_mandir}/man8/makewhatis.mandoc.8.gz

%{_sbindir}/update-alternatives --install %{_bindir}/soelim soelim %{_bindir}/soelim.mandoc 200 \
    --slave %{_mandir}/man1/soelim.1.gz soelim.1.gz %{_mandir}/man1/soelim.mandoc.1.gz

%{_sbindir}/update-alternatives --install %{_mandir}/man7/roff.7.gz roff.7.gz %{_mandir}/man7/roff.mandoc.7.gz 200 \
    --slave %{_mandir}/man7/eqn.7.gz eqn.7.gz %{_mandir}/man7/eqn.mandoc.7.gz \
    --slave %{_mandir}/man7/tbl.7.gz tbl.7.gz %{_mandir}/man7/tbl.mandoc.7.gz

%{_sbindir}/update-alternatives --install %{_mandir}/man7/man.7.gz man.7.gz %{_mandir}/man7/man.mandoc.7.gz 200

%preun
if [ $1 -eq 0 ]; then
    %{_sbindir}/update-alternatives --remove man %{_bindir}/man.mandoc
    %{_sbindir}/update-alternatives --remove soelim %{_bindir}/soelim.mandoc
    %{_sbindir}/update-alternatives --remove roff.7.gz %{_mandir}/man7/roff.mandoc.7.gz
    %{_sbindir}/update-alternatives --remove man.7.gz %{_mandir}/man7/man.mandoc.7.gz
fi

%files
%license LICENSE
%{_bindir}/demandoc
%{_bindir}/mandoc
%{_bindir}/apropos.mandoc
%ghost %{_bindir}/apropos
%{_bindir}/man.mandoc
%ghost %{_bindir}/man
%{_bindir}/soelim.mandoc
%ghost %{_bindir}/soelim
%{_bindir}/whatis.mandoc
%ghost %{_bindir}/whatis
%{_sbindir}/makewhatis.mandoc
%ghost %{_sbindir}/makewhatis
%{_mandir}/man1/demandoc.1.gz
%{_mandir}/man1/mandoc.1.gz
%{_mandir}/man1/apropos.mandoc.1.gz
%ghost %{_mandir}/man1/apropos.1.gz
%{_mandir}/man1/man.mandoc.1.gz
%ghost %{_mandir}/man1/man.1.gz
%{_mandir}/man1/soelim.mandoc.1.gz
%ghost %{_mandir}/man1/soelim.1.gz
%{_mandir}/man1/whatis.mandoc.1.gz
%ghost %{_mandir}/man1/whatis.1.gz
%{_mandir}/man5/mandoc.conf.5.gz
%{_mandir}/man5/mandoc.db.5.gz
%{_mandir}/man7/eqn.mandoc.7.gz
%ghost %{_mandir}/man7/eqn.7.gz
%{_mandir}/man7/mandoc_char.7.gz
%{_mandir}/man7/man.mandoc.7.gz
%ghost %{_mandir}/man7/man.7.gz
%{_mandir}/man7/mdoc.7.gz
%{_mandir}/man7/roff.mandoc.7.gz
%ghost %{_mandir}/man7/roff.7.gz
%{_mandir}/man7/tbl.mandoc.7.gz
%ghost %{_mandir}/man7/tbl.7.gz
%{_mandir}/man8/makewhatis.mandoc.8.gz
%ghost %{_mandir}/man8/makewhatis.8.gz

%files -n libmandoc-devel
%license LICENSE
%{_libdir}/libmandoc.a
%{_includedir}/*.h
%{_mandir}/man3/*.3*

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.6-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.6-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.6-3
- Rebuilt for OpenCloudOS Stream 23

* Wed Mar 8 2023 Shuo Wang <abushwang@tencent.com> - 1.14.6-2
- update url

* Thu Feb 2 2023 Shuo Wang <abushwang@tencent.com> - 1.14.6-1
- initial build
